@@ -3,9 +3,9 @@
 from enkanetwork import EnkaNetworkAPI,Assets
 import logging,asyncio,random, os, datetime
 from threading import Thread
-from src.utils.CreatBanner import weaponAdd,nameBanner,stats,constant,create_picture,talants,artifacAdd,signature,appedFrame,openUserImg 
-from src.utils.translate import translate
-from enc_error import ENCardError
+from .src.utils.CreatBanner import weaponAdd,nameBanner,stats,constant,create_picture,talants,artifacAdd,signature,appedFrame,openUserImg 
+from .src.utils.translate import translate
+from .enc_error import ENCardError
 
 asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
 logging.getLogger('enkanetwork.assets').setLevel(logging.CRITICAL)
