@@ -343,7 +343,7 @@ def appedFrame(frame,weaponRes,nameRes,statRes,constantRes,talatsRes,artifacRes,
 def generationOne(characters,assets,img,adapt,signatureRes,lvl,splash):
     try:
         if splash:
-            frame = create_picture(assets,characters.id,img,adapt,characters.image.banner.url)
+            frame = create_picture(assets,characters.id,img,adapt,splash = characters.image.banner.url)
         else:
             frame = create_picture(assets,characters.id,img,adapt)
         weaponRes = weaponAdd(characters.equipments[-1],lvl)
